<?php

namespace Drupal\standwithukraine\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\standwithukraine\StandWithUkraineTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a block to display a message on the background of the flag.
 *
 * @Block(
 *   id = "standwithukraine_block",
 *   admin_label = @Translation("StandWithUkraine"),
 * )
 */
class StandWithUkraineBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Creates a StandWithUkraineBlock instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    ConfigFactoryInterface $config_factory
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  use StandWithUkraineTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'inherit' => TRUE,
      'url' => NULL,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $link = Link::createFromRoute(
      $this->t('the settings page'),
      'standwithukraine.settings',
      [],
      [
        'attributes' => [
          'target' => '_blank',
        ],
      ]
    );

    $url = $this->configFactory->get('standwithukraine.settings')->get('url');

    $form['inherit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Inherit link'),
      '#description' => $this->t('Re-use value from the same field on @url.', [
        '@url' => $link->toString(),
      ]),
      '#default_value' => $this->configuration['inherit'],
      '#disabled' => empty($url),
    ];

    $this->alter($form, $this->configuration['url']);

    if ($form['inherit']['#disabled']) {
      if ($form['inherit']['#default_value']) {
        $form['inherit']['#default_value'] = FALSE;
      }
    }
    else {
      $form['url']['#states'] = [
        'disabled' => [
          ':input[name="settings[inherit]"]' => [
            'checked' => TRUE,
          ],
        ],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['inherit'] = $form_state->getValue('inherit');
    $this->configuration['url'] = $form_state->getValue('url');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $url = $this->configFactory->get('standwithukraine.settings')->get('url');

    return [
      '#theme' => 'standwithukraine',
      '#url' => $this->configuration['inherit'] && !empty($url)
        ? $url : $this->configuration['url'],
      '#attached' => [
        'library' => ['standwithukraine/common'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    return Cache::mergeTags(parent::getCacheTags(), ['standwithukraine']);
  }

}
