<?php

namespace Drupal\standwithukraine\Service;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;

/**
 * Defines the access service.
 */
class StandWithUkraineAccess implements StandWithUkraineAccessInterface {

  /**
   * The current active user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorageInterface
   */
  protected $storage;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    AccountProxyInterface $current_user,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->currentUser = $current_user;
    $this->storage = $entity_type_manager->getStorage('user_role');
  }

  /**
   * {@inheritdoc}
   */
  public function isAllowed($permission) {
    foreach ($this->currentUser->getRoles() as $role_id) {
      /** @var \Drupal\user\RoleInterface $role */
      $role = $this->storage->load($role_id);

      if (
        !$role->isAdmin() &&
        (
          $role->hasPermission('disable standwithukraine features') ||
          $role->hasPermission($permission)
        )
      ) {
        return FALSE;
      }
    }

    return TRUE;
  }

}
