<?php

namespace Drupal\standwithukraine\Service;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;

/**
 * Defines the favicon service interface.
 */
interface StandWithUkraineFaviconInterface {

  /**
   * The default ratio for an unknown theme.
   *
   * The first half of the space is for blue color and the second half space for
   * yellow color.
   */
  const UNDEFINED_RATIO = 50;

  /**
   * The default ratio for a known theme.
   *
   * Use a specific ratio for themes that are provided by Drupal core or someone
   * else who is using favicon in Drupal logo style (image of drop).
   */
  const DEFINED_RATIO = 60;

  /**
   * The predefined themes list.
   */
  const THEMES = [
    'bartik',
    'bootstrap',
    'claro',
    'olivero',
    'seven',
    'stark',
  ];

  /**
   * The supported media types.
   */
  const TYPES = ['image/png', 'image/vnd.microsoft.icon', 'image/x-icon'];

  /**
   * StandWithUkraineFavicon constructor.
   *
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache
   *   The cache.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger channel factory.
   * @param \Drupal\Core\File\FileUrlGeneratorInterface|null $file_url_generator
   *   (optional) The file URL generator. Defaults to NULL.
   */
  public function __construct(
    CacheBackendInterface $cache,
    ConfigFactoryInterface $config_factory,
    LoggerChannelFactoryInterface $logger_factory,
    FileUrlGeneratorInterface $file_url_generator = NULL
  );

  /**
   * Extract images from favicon and style them in Ukraine flag colors.
   *
   * @param string $theme
   *   The theme name.
   *
   * @return array
   *   An array of arrays. Each key is the theme name (e.g. seven), and each
   *   value is an array of paths to images, keyed by dimensions (e.g. 32x32).
   */
  public function build($theme);

  /**
   * Check if a file type is one from the list of processable.
   *
   * @param string $type
   *   The MIME type.
   *
   * @return bool
   *   TRUE if so.
   */
  public function isSupported($type);

}
